@set_windows_device
@spectrum
@colorbar

pro plot_L_theta_phi_2

; This routine makes a 2 panel plot of radiance(theta,phi) at a given depth and wavelength
;    The left panel is a globe with radiance(theta,phi) plotted as radiance(latitude,longitude)
;    The right panel is a color bar showing the color-coded values
;
;     The input file fndata is a HYDROLIGHT 5.0 "Lroot.txt" digital output file, which
;     contains the total radiance L(depth,theta,phi,wavelength)

;  the common blocks give access to all data read from a Lroot.txt file

;  This common block is for use ONLY with HYDROLIGHT L files
common cLdata, nz,ntheta,nphi,nwave,depth,theta,phi,wavelength,radiance

; radiance = fltarr(nz,ntheta,nphi,nwave);
;            depth index 0 is in-air; depth index 1 is in water at depth 0
;            itheta = 0 and jphi = 0 is Ld, itheta = ntheta-1 and jphi = 0 is Lu
; depth = fltarr(nz); depth(0) = -1.0 for air; depth(1) = 0.0 for in water
;
;
;  ***** read in all data from the HydroLight Droot.txt file
;
dirname = '.\'  ; directory where to look first

Lfilename = dialog_pickfile(path=dirname,filter=['L*.txt'],title='Select the HydroLight Lroot.txt file')

; read the entire Droot.txt file.  Information comes back via the common blocks.

read_H_Lfile,Lfilename ; to read a HYDROLIGHT Lroot.txt file

; Hydrolight L files have theta = 0 (Ld) to 180 (Lu), and phi = 0 to 360.
; Must covert to Lat = -90 to + 90 (0 is the Equator), and long = -180 to +180 (0 is Greenwich)

Lat = 90.0 - theta
Lon = phi - 180.0

; extract radiance at a given depth and wavelength
; theta = 0 (downwelling photons) maps to the north pole (lat = 90) for viewing direction

iz = 0 ; in air
iw = 20 ; 555 nm for this example
print,' wavelength = ',wavelength[iw]

; transpose radiance(theta,phi) to radiance(phi,theta) for association with rad(lat,long)
; reverse the theta/lat values to change from photon to viewing direction
rad = reform(transpose(alog10(radiance(iz,*,*,iw))))
rad = reverse(rad,1)
help,rad

;  select output device
;
;Set_windows_device

; adjust settings for a square plot on screen

set_plot,'win'

xwin = 1000
ywin = 900

   window,xsize=xwin,ysize=ywin

   device,decomposed=0 ; for true color display settings

!p.color=0

!p.charsize = 1.25
!p.thick = 2.0
!p.charthick = 1.5
!x.margin = [10.,4.]
!y.margin = [4.,4.]

; select a color table

spectrum

;  define the 2 panel layout

reg = fltarr(2,4,/nozero)

xside = 0.8
yside = 0.9
xll = 0.02
yll = 0.02
reg(0,*) = [xll,yll,xll+xside,yll+yside] ; [xll,yll,xur,yur] in normal coord
xll = 0.85
yll = 0.05
reg(1,*) = [xll,yll,xll+1.0-xside,yll+yside]


; plot the globe in the left panel
!p.region = reg(0,*)

;
; set up to plot (phi, theta) values as (latitude, longitude) on a globe

map_set,10.0,-30.0,0.0, /ortho,color=226  ; plot in white so frame lines don't show


radmax = max(rad,min=radmin)
print,' rad max and min = ',radmax,radmin

; set contours for this particular plot
conmin = -2.5
conmax = 2.0
nlevels = 50
convals = conmin + (conmax-conmin)*findgen(nlevels)/nlevels

; stretch the violet to red spectrum color table to fit min to max values
stretch = 2.5 ; determined by trial and error
colors = 25 + stretch*indgen(nlevels)


; to contour at the original Hydrolight theta-phi resolution, use:
;contour,rad,lon,lat,/overplot, levels=convals,c_colors=colors,/cell_fill;, $;c_labels=clabels, $
;       xstyle=1,ystyle=1,c_thick=2,c_charsize=1.25,c_charthick=2,/overplot,color=0


; to interpolate and smooth the Hydrolight values for better appearance, use:
degsize = 5 ; for a 5 x 5 degree final grid
radsmooth = min_curve_surf(rad,xvalues=lon,yvalues=lat,gs=[degsize,degsize])
help,radsmooth
nlons = 360/degsize + 1
nlats = 180/degsize + 1
lonsmooth = degsize*findgen(nlons) - 180.0
latsmooth = degsize*findgen(nlats) - 90.0
contour,radsmooth,lonsmooth,latsmooth,/overplot, levels=convals,c_colors=colors,/cell_fill


; overplot the Hydrolight theta-phi computational grid

; lines of constant latitude
lat0= replicate(0,nphi)
;  plot the equator
plots,lon,lat0,linestyle=0,thick=2,color=0
;
latgrid = [-85,-75,-65,-55,-45,-35,-25,-15,-5,5,15,25,35,45,55,65,75,85]
for ilat=0,n_elements(latgrid)-1 do begin

  lats = replicate(latgrid(ilat),nphi)
  plots,lon,lats,linestyle=1,thick=2,color=0

endfor
;
;  overplot lines of constant longitude
;
ngen = ntheta-2
lats=5+10*findgen(ngen) - 90.0
lons0=lats*0.0 + 1.0
for il=0,nphi-1 do begin

  lons = 7.5 + lons0*il*360.0/nphi
  plots,lons,lats,linestyle=1,thick=2,color=0

endfor
;
; phi = 0 line
ngen = ntheta
lats = 10 + 10*findgen(ngen) - 90.0
lons = lons0*il*360.0/nphi
plots,lons,lats,linestyle=0,thick=2,color=0

; add a color bar at the right, using D. Fannings Open Source code

; plot the colorbar in the right panel
!p.region = reg(1,*)
colorbar,position=[0.93,0.10,0.98,0.8],range=[conmin,conmax],/vertical, $
         bottom=25,ncolors=stretch*nlevels,format='(f4.1)',divisions=9, $
         title='log!d10!n[radiance (W m!u-2!n sr!u-1!n nm!u-1!n)]',charsize=2.0

;
print,'end plot_L_theta_phi_2'
end


