@set_windows_device
;@LUTcolor
@spectrum
@colorbar

pro plot_L_theta_phi
;
;     The input file fndata is a HYDROLIGHT 5.0 "Lroot.txt" digital output file, which
;     contains the total radiance L(depth,theta,phi,wavelength)
;
;       one free-format input record read from the keyboard to override the
;          default y axis range and scaling, if desired

;  the common blocks give access to all data read from a Lroot.txt file

;  This common block is for use ONLY with HYDROLIGHT L files
common cLdata, nz,ntheta,nphi,nwave,depth,theta,phi,wavelength,radiance

; radiance = fltarr(nz,ntheta,nphi,nwave);
;            depth index 0 is in-air; depth index 1 is in water at depth 0
;            itheta = 0 and jphi = 0 is Ld, itheta = ntheta-1 and jphi = 0 is Lu
; depth = fltarr(nz); depth(0) = -1.0 for air; depth(1) = 0.0 for in water
;
;
;  ***** read in all data from the HydroLight Droot.txt file
;
dirname = '.\'  ; directory where to look first

Lfilename = dialog_pickfile(path=dirname,filter=['L*.txt'],title='Select the HydroLight Lroot.txt file')

; read the entire Droot.txt file.  Information comes back via the common blocks.

read_H_Lfile,Lfilename ; to read a HYDROLIGHT Lroot.txt file

; Hydrolight L files have theta = 0 (Ld) to 180 (Lu), and phi = 0 to 360.
; Must covert to Lat = -90 to + 90 (0 is the Equator), and long = -180 to +180 (0 is Greenwich)

Lat = 90.0 - theta
Lon = phi - 180.0

; extract radiance at a given depth and wavelength
; theta = 0 (downwelling photons) maps to the north pole (lat = 90) for viewing direction

iz = 0 ; in air
iw = 20 ; 555 nm
print,' wavelength = ',wavelength[iw]

rad = reform(transpose(alog10(radiance(iz,*,*,iw))))
rad = reverse(rad,1)
help,rad

;  select output device
;
;Set_windows_device

; settings for a square plot

set_plot,'win'

xwin = 910
ywin = 900
   ; settings for default Windows display.
   ; the default window is 1/4 of the screen
   window,xsize=xwin,ysize=ywin

   device,decomposed=0 ; for true color display settings

   ;  set for black plot on white background (can override)

 ;  !p.background=255
   !p.color=0
   ; set scale = 0 to get proper windows plot (why this
   ;               works I don't know, but it does)

; default settings for best appearance on the screen
; (can override in the calling program)
!p.charsize = 1.25
!p.thick = 2.0
!p.charthick = 1.5
!x.margin = [10.,4.]
!y.margin = [4.,4.]

; select a color table
;Lutcolor
spectrum

;
; set up to plot (theta,phi) values as (latitude, longitude) on a globe

map_set,10.0,-30.0,0.0, /ortho,color=226  ; plot in white so frame lines don't show
;


;  normalize for plotting neatness
radmax = max(rad,min=radmin)
print,' rad max and min = ',radmax,radmin

conmin = -2.5
conmax = 2.0
nlevels = 50
convals = conmin + (conmax-conmin)*findgen(nlevels)/nlevels
;print,' convals = ',convals
colors = 25 + 3*indgen(nlevels)
;print,' colors = ',colors

; to contour at the original Hydrolight theta-phi resolution, use:
;contour,rad,lon,lat,/overplot, levels=convals,c_colors=colors,/cell_fill;, $;c_labels=clabels, $
;       xstyle=1,ystyle=1,c_thick=2,c_charsize=1.25,c_charthick=2,/overplot,color=0


; to interpolate and smooth the Hydrolight values for better appearance, use:
degsize = 5 ; for a 5 x 5 degree final grid
radsmooth = min_curve_surf(rad,xvalues=lon,yvalues=lat,gs=[degsize,degsize])
help,radsmooth
nlons = 360/degsize + 1
nlats = 180/degsize + 1
lonsmooth = degsize*findgen(nlons) - 180.0
latsmooth = degsize*findgen(nlats) - 90.0
contour,radsmooth,lonsmooth,latsmooth,/overplot, levels=convals,c_colors=colors,/cell_fill


;  plot lines of constant latitude
;

; overplot the theta-phi computational grid

lat0= replicate(0,nphi)
;  plot the equator
plots,lon,lat0,linestyle=0,thick=2,color=0
;
latgrid = [-85,-75,-65,-55,-45,-35,-25,-15,-5,5,15,25,35,45,55,65,75,85]
for ilat=0,n_elements(latgrid)-1 do begin
  ;lats = 5.0 + lats0 + 90.0 - theta(ilat)
  lats = replicate(latgrid(ilat),nphi)
;  print,ilat
;  print,lats
;  print,lon
plots,lon,lats,linestyle=1,thick=2,color=0

endfor
;
;  overplot lines of constant longitude
;
;  note; can change the number of points generated, via ngen, to get
;  a nice looking polar cap
ngen = ntheta-2
lats=5+10*findgen(ngen) - 90.0
lons0=lats*0.0 + 1.0
for il=0,nphi-1 do begin
lons = 7.5 + lons0*il*360.0/nphi
plots,lons,lats,linestyle=1,thick=2,color=0
;index = where(lats ge 0)
;plots,lons(index),lats(index),linestyle=1,thick=1,color=1
endfor
;
; phi = 0 line
ngen = ntheta
lats = 10 + 10*findgen(ngen) - 90.0
lons = lons0*il*360.0/nphi
plots,lons,lats,linestyle=0,thick=2,color=0

; add a color bar at the right, using D. Fannings Open Source code

colorbar,position=[0.88,0.10,0.95,0.90],range=[conmin,conmax],title='log(radiance)',/vertical, $
         bottom=25,ncolors=3*nlevels

;
print,'end plot_L_theta_phi'
end


