pro read_H_Lfile,Lfilename
;
;   core IDL routine on file read_H_Lfile.pro
;
;   This routine reads in an entire file of ascii digital data on the HYDROLIGHT v5
;   Lroot.txt format, as written by the HydroLight 5 HE5\code\Hydrolight\writerad_HL.f routine.
;
;   The Lroot.txt files contain the entire total radiance distribution from a HydroLight run.
;   Depth -1.0 is the in-air values, which include water-leaving and surface reflected radiance
;   in the upwelling values
;
;   theta and phi are the directions of photon travel.
;   theta = 0 is the nadir direction (photons heading straight down)
;   The downwelling radiance Ld is thus 0 <= theta <= 90
;   The upwelling   radiance Lu is 90 <= theta <= 180
;   The sun is in the phi = 0 direction, so the direct solar photons are traveling
;   in the phi = 180 direction and in the theta < 90 (downward) direction
;
;   Lfilename, the path and name of the Lroot.txt file to be read, is passed in from the calling routine.
;
;   All data on the file are made available to the IDL calling program via the common block.
;
;  This common block is for use ONLY with HYDROLIGHT L files
common cLdata, nz,ntheta,nphi,nwave,depth,theta,phi,wavelength,radiance

title = ' ' ; misc strings
;
;  open the file for reading
;
openr,lun,Lfilename,/get_lun
;
; read the first file header
readf,lun,format='(a)',title
print,'Reading HydroLight 5 L-file titled:'
print,'    ',title
;
; read the grid dimensions
nz = 0 ; make integers
ntheta = 0
nphi = 0
nwave = 0
; nz as read is the number of in-water depths plus one for in air values as index 0
readf,lun,format='(a40,5i5)',title,nz,ntheta,nphi,nwave
print,' nz, ntheta, nphi, nwave =',nz,ntheta,nphi,nwave
;
; skip the next 7 header records
for i=0,6 do readf,lun,format='(a)',title

;  define arrays of the appropriate sizes
;
depth = fltarr(nz) ; includes depth = -1 for in air values as index 0
theta = fltarr(ntheta)
phi = fltarr(nphi)
wavelength = fltarr(nwave)
radiance = fltarr(nz,ntheta,nphi,nwave); depth index 0 is in-air; depth index 1 is in water at depth 0

readrec = fltarr(5)

; read the entire L data file

for iw=0,nwave-1 do begin
  for iz=0,nz-1 do begin
    for it=0,ntheta-1 do begin
      for ip=0,nphi-1 do begin

        readf,lun,readrec,format='(f8.2,3f8.1,e15.5)

        depth[iz] = readrec[0]
        theta[it] = readrec[1]
        phi[ip] = readrec[2]
        wavelength[iw] = readrec[3]
        radiance[iz,it,ip,iw] = readrec[4]

      endfor
    endfor
  endfor
endfor

print,' last rec read: ',readrec
free_lun,lun
;
return
end

